CompactFormatter

Struct CompactFormatter 

pub struct CompactFormatter {}
A formatter which outputs with no excess whitespace and does not check for valid BibTeX.

Implementations

Source

impl CompactFormatter

pub fn validate(self) -> ValidatingFormatter<CompactFormatter>

Return a formatter with the same output, except that also validates the generated BibTeX.