pub struct PrettyFormatter {}Expand description
A formatter which outputs with normal whitespace and does not check for valid BibTeX.
Implementations
Sourceimpl PrettyFormatter
impl PrettyFormatter
Sourcepub fn validate(self) -> ValidatingFormatter<PrettyFormatter>
pub fn validate(self) -> ValidatingFormatter<PrettyFormatter>
Return a formatter with the same output, except that also validates the generated BibTeX.