pub struct CompactFormatter {}Expand description
A formatter which outputs with no excess whitespace and does not check for valid BibTeX.
Implementations
Sourceimpl CompactFormatter
impl CompactFormatter
Sourcepub fn validate(self) -> ValidatingFormatter<CompactFormatter>
pub fn validate(self) -> ValidatingFormatter<CompactFormatter>
Return a formatter with the same output, except that also validates the generated BibTeX.